#
# spec file for package raspberrypi-firmware-dt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           raspberrypi-firmware-dt
Version:        2018.03.14
Release:        lp150.1.1
Summary:        Device trees for the Raspberry Pi firmware loader
License:        GPL-2.0
Group:          System/Boot
Url:            https://github.com/raspberrypi/linux/
Source:         raspberrypi-firmware-dt-%{version}.tar.xz
Source1:        rpi3-hdmi-overlay.dts
Source2:        upstream-mmc-overlay.dts
Source3:        upstream-aux-interrupt-overlay.dts
Source4:        get-from-git.sh
Requires:       raspberrypi-firmware
BuildRequires:  dtc
BuildRequires:  raspberrypi-firmware
BuildArch:      noarch

%description
This package provides additional device tree base files as well as overlays
for the Raspberry Pi boot process.

%prep
%setup

%build
SRCDIR=`pwd`
mkdir pp
PPDIR=`pwd`/pp

export DTC_FLAGS="-R 4 -p 0x1000 -@ -H epapr"
for dts in arch/arm/boot/dts/bcm27*dts arch/arm64/boot/dts/broadcom/bcm27*dts; do
    target=$(basename ${dts%*.dts})
    cpp -x assembler-with-cpp -undef -D__DTS__ -nostdinc -I. -I$SRCDIR/include/ -I$SRCDIR/scripts/dtc/include-prefixes/ -P $dts -o $PPDIR/$target.dts
    dtc $DTC_FLAGS -I dts -O dtb -i ./$(dirname $dts) -o $PPDIR/$target.dtb $PPDIR/$target.dts
done

export DTC_FLAGS="-R 0 -p 0 -@ -H epapr"
for dts in arch/arm/boot/dts/overlays/*dts %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
    target=$(basename ${dts%*.dts})
    target=${target%*-overlay}
    mkdir -p $PPDIR/overlays
    cpp -x assembler-with-cpp -undef -D__DTS__ -nostdinc -I. -I$SRCDIR/include/ -I$SRCDIR/scripts/dtc/include-prefixes/ -P $dts -o $PPDIR/overlays/$target.dts
    dtc $DTC_FLAGS -I dts -O dtb -i ./$(dirname $dts) -o $PPDIR/overlays/$target.dtbo $PPDIR/overlays/$target.dts
done

%define dtbdir /boot/vc
%install
install -m 700 -d %{buildroot}%{dtbdir}/
install -m 700 -d %{buildroot}%{dtbdir}/overlays

for dtb in pp/*.dtb; do
    install -m 644 $dtb %{buildroot}%{dtbdir}/
done

for dtbo in pp/overlays/*.dtbo; do
    install -m 644 $dtbo %{buildroot}%{dtbdir}/overlays/
done

%post
if mountpoint -q /boot/efi && [ ! -L /boot/efi ]; then
    cp -r /boot/vc/*dtb /boot/vc/overlays /boot/efi/
fi

%files
%defattr(-,root,root)
%license COPYING
%dir /boot/vc/overlays
/boot/vc/*dtb
/boot/vc/overlays/*dtbo

%changelog
* Wed Mar 14 2018 agraf@suse.com
- Update to ad350a581a44 (2018-03-14)
  - Add rpi3-plus dtb which gives us a proper compatible string
* Wed Mar 14 2018 agraf@suse.com
- Update to d35408f26 (2018-03-13)
  - Fix wifi detection on RPi3 (bsc#1085262)
* Mon Feb 19 2018 agraf@suse.com
- Add overlays to match previous U-Boot provided DT:
  - rpi3-hdmi-overlay.dts
  - upstream-mmc-overlay.dts
  - upstream-aux-interrupt-overlay.dts
* Fri Feb 16 2018 agraf@suse.com
- Initial commit of 7ba7fbcc4 (2018-02-02)
